Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(691)

Unified Diff: net/quic/quic_unacked_packet_map_test.cc

Issue 977453002: Discard acks from QUIC's UnackedPacketMap when the map is larger than (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@Remove_TCP_and_BBR_max_congestion_window_87346681
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/quic/quic_unacked_packet_map.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/quic_unacked_packet_map_test.cc
diff --git a/net/quic/quic_unacked_packet_map_test.cc b/net/quic/quic_unacked_packet_map_test.cc
index 2077c676b129dd04cfa27af79df4082b826fa3e6..0e1d68aa08e49e743bf27db3ab6deab5a62159ce 100644
--- a/net/quic/quic_unacked_packet_map_test.cc
+++ b/net/quic/quic_unacked_packet_map_test.cc
@@ -126,9 +126,9 @@ TEST_F(QuicUnackedPacketMapTest, RttOnly) {
TEST_F(QuicUnackedPacketMapTest, DiscardOldRttOnly) {
// Acks are only tracked for RTT measurement purposes, and are discarded
- // when more than 200 accumulate.
- const size_t kNumUnackedPackets = 200;
- for (size_t i = 1; i < 400; ++i) {
+ // when more than 2500 accumulate.
+ const size_t kNumUnackedPackets = 2500;
+ for (size_t i = 1; i < 3000; ++i) {
unacked_packets_.AddSentPacket(CreateNonRetransmittablePacket(i), 0,
NOT_RETRANSMISSION, now_, kDefaultAckLength,
false);
« no previous file with comments | « net/quic/quic_unacked_packet_map.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698